bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 23. Aventiure
___________________________________________________ #### <Wie Krimhilt ir leit gedaht ze rechen>
| ### it vil grozen eren daz ist alwar ### wonte si mit ein ander vnz an daz sibende iar ### div cit div kuniginne eins svns was genesen ### des kvnde der kvnic Ecele nimmer vrolicher wesen
###### 1328 | ### Sin wolde niht erwinden sin wrbe sint ### daz getovfet wurde daz Ecelen kint ### nach cristenlichem rehte Ortliep wart ez genant ### des wart vil michel vreude vber al des Ecelen lant
###### 1329 | ### Swaz ie guoter tvgende an vron Helchen lac ### der vleiz sich nv vro Kriemhilt darnach vil manigen tac ### die site si lerte Herrat div ellende meit ### div hete tvgentlichen nach Helchen grozlic leit
###### 1330 | ### Den vremden vn– den kvnden was si vil wol bekant ### die iahen daz nie vrovwe beseze kvniges lant ### bezzer vn– milter daz heten si fur war ### daz lob si truoc zen Hunen vnz an daz drivzehende iar
###### 1331 | ### Nv hete si wol erkvnet daz ir nieman widerstuont ### also noch fursten wibe kuniges reken tuont ### vn– daz si alle zit zwelf kvnige vor ir sach ### si gedaht ovch maniger leide der ir deheime gesach [54b]
###### 1332 | ### Si daht ovch maniger ern von Niblunge lant ### der si was gewaltic vn– die ir Hagnen hant ### mit Sifrides tode hete gar benomen ### ob im daz ovch immer ze leide mohte komen
###### 1333 | ### Daz geschehe ob ich in bringe mohte in dize lant ### ir trounte daz ir gienge vil dike an der hant ### Giselher ir bruoder si kust in ze aller stunt ### vil ofte in semftem slafe sit war in erbeit kvnt
###### 1334 | ### Ich wene der ubel valant Kriemhit daz geriet ### daz si sich mit fruntschefte von Giselhere schiet ### den si durch suone kuste in Burgonden lant ### do begond ir aber svlwen von heizen trehen ir gewant
###### 1335 | ### Ez lac ir an dem herzen spat vn– vruo ### wie man si ane schulde brehte dar zuo ### daz si muose minnen einen heidenischen man ### die not die het ir Hagne vn– Gunther getan
###### 1336 | ### Des willen in ir herzen chom si vil selten abe ### si gedaht ich bin so riche vn– han so groze habe ### daz ich minen vienden gefuoge noch ein leit ### des were et ich <Hagnen> von Trony gerne bereit
###### 1337 | ### Nach den getriwen iamere dike daz herze min ### die mir da leide taten mohte ich bi den sin ### so wurde wol errochen mines vriundes lip ### des ich kume erbeiten sprach daz Ecelen wip
###### 1338 | ### Ze liebe si do heten al des kuniges man ### die Kriemhilde reken daz was vil wol getan ### der kameren pflac Echewart da von er vrivnt gewan ### Kriemhilde willen kvnde nieman vnderstan
###### 1339 | ### Si dahte zallen ziten ich wil den kvnich biten ### daz er ir des choende mit guetlichen siten ### daz man ir vrivnde brehte in der Hunen lant ### des argen willen niemen an der kvniginne vant
###### 1340 | ### Do si eines nahtes bi dem kvnige lac ### mit armen vmbevangen het er si als er phlac ### die edelen vrovwen truotten si was im so sin lip ### do gedaht ir viende daz vil wetliche wip
###### 1341 | ### Si sprach zuo dem kvnige vil lieber herre min ### ich wole ivch hiten gerne moehte ez mit hulden sin ### daz ir mich sehen liezet ob ich daz het versolt ### ob ir den minen vrivnden weret inneclichen holt
###### 1342 | ### Do sprach der kvnich riche getriwe was sin mvot ### ich bringe ivch des wol innen swa liep vn– guot ### den rechen widerfuore des mvose ich viende han ### wand ich von vrivndes minne nie bezzer vrivnde gewan
###### 1343 | ### Do sprach div kvniginne iv ist daz wol geseit ### ich han vil hohe mage darvmbe ist mir so leit ### daz mich die so selten ruochent hie gesehen ### ich hoere min die lûte niwan fur elende iehen
###### 1344 | ### Do sprach der kvnich Ecele vil liebiv vrowe min ### divht ez si niht ze verre so luede ich vber Rin [55a] ### swel ir da gerne sehet varn her in min lant ### des vrovvte sch div vrovwe do si den willen sin ervant
###### 1345 | ### Si sprach wolt ir mit trvwe leisten herre min ### so svlt ir boten senten ze Wormz vber Rin ### so enbvte ich minen vrivnden des ich da habe mvot ### so kvmt vns her ze lande vil manich edel riter guot
###### 1346 | ### Er sprach swem ir gebietet so lazet ez geschehen ### irn kvndet iwer vrivnde so gerne niht gesehen ### als ich si gesehe der edelen voten kint ### mich mvot daz harte sere daz si vns so lange vremde sint
###### 1347 | ### Ob ez dir wol gevalle vil liebe vrovwe min ### so wold ich gerne senden nach den vrivnden din ### die minen videlere in Bvrgonden lant ### die guoten videlere hiez er bringen san cehant
###### 1348 | ### Si ilten harte balde da der kvnich saz ### bi der kvnnigin er saget in beiden daz ### si solten boten werden in Burgonden lant ### do hiez erin bereiten harte herlich gewant
###### 1349 | ### Vier vn– zweinzech reken bereite man do kleit ### ovch wart im von dem kvnige div botschaft geseit ### wie er da laden solde Gvnther vn– sine man ### Kriemhilt div vrovwe si svnder sprechen began
###### 1350 | ### Do sprach der kvnich rike ich sage wie ir tvot ### ich enbivte minen vrivnden lieb vnd allez gvot ### daz si ruochen riten her in miniv lant ### ich han so lieber geste harte wenic noch bekant
###### 1351 | ### Vnd ob si mines willen wellen iht began ### die Kriemhilde mage daz si des niht lan ### si en komen an disem svmere zvo miner hohgecit ### wand vil der minen wunne an minen kuone magen lit
###### 1352 | ### Do sprach der videlere der stolze Swæmelin ### wenne sol iwer hochcit in disen landen sin ### daz wir iwern vrivnden daz kvnnen dort gesagen ### do sprach der kvnich Ecel cen nahsten svnwenden tagen
###### 1353 | ### Wir tuon swaz ir gebietet sprach do Wærbelin ### in ir kemenaten bat div kvnigin ### bringen tovgenlichen da die boten si gesprach ### da von vil manigem degne sid wenich <liebes> gesach
###### 1354 | ### Si sprach cen boten beiden nv dient michel guot ### daz ir minen willen vil guetlichen tuot ### vnd saget swaz ich enbiete heim in vnser lant ### ich mache ivch guotes rike vnd gib iv herlich gewant
###### 1355 | ### Vnd swaz ir miner vrivnde immer mvget gesehen ### ze Wormez bi dem Rine den svlt ir niht veriehen ### daz ir noch ie gesehet betruobet minen mvot ### vnd saget minen dienst den helden kuone vn– guot
###### 1356 | ### Bittet daz si leisten daz Ruediger in enbot ### vn– mich da mite scheiden von aller miner not ### die Hv^nen wellent wenen daz ich an vrivnde si ### ob ich ein riter were ich choeme in ettewenne bi [55b]
###### 1357 | ### Vnd saget ovch Gernote dem edeln bruoder min ### daz im iernen mvge ce der werlde holder sin ### bitet daz er mir bringe her in dize lant ### vnser besten vrivnde daz ez vns ze eren si gewant
###### 1358 | ### So saget ovch geselle daz er wol gedenke daran ### daz ich von sinen schvlden nie leides niht gewan ### des sehen in vil gerne hie die ovgen min ### ich heten hie vil gerne dvrch die grozen triwe min
###### 1359 | ### Saget ovch miner mvoter die ere die ich han ### vn– ob von Troni Hagne dort welle bestan ### wer si dan wisen solde durch div lant ### den sin die wege von kinde herzelichen wol bekant
###### 1360 | ### Die boten nine wessen wa von daz was getan ### daz si von Trony Hagnen niht beliben solten lan ### dort bi dem Rine ez wart in sider leit ### mit in was manigem degne zem grimmen tode widerseit
###### 1361 | ### Brieve vn– boteschaft was in nv gegeben ### si fuorten guotes riche vn– moehten schoene leben ### vrlovb gab in Ecele vn– ovch sin schoene wip ### in was von guoten wæte wol gecieret der lip

<<< Übersicht <<< vorige Seite nächste Seite >>>